==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>العرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>سجل نظيف</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>هل أنت متأكد أنك تريد مسح السجل؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>تؤكد</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>اليوم</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 أيام</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 أسبوع</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 شهر</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 أشهر</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">تصدير</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>تصدير</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>طارئ</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>إنتباه</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>خطر</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>التصحيح</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>تسجيل الدخول</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>الإقلاع</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation> TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html) </translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>ملف التصدير</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>الفترة :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application list:</source>
        <translation>لائحة البرنامج :</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>نوع الحدث:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستعمل :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>الإجراء:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>سجل الإقلاع</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>سجل إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>سجل تسجيل الدخول</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>التصحيح</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>طارئ</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>إنتباه</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>خطر</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>عارض السجلات</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>عارض السجلات هو أداة مفيدة لعرض سجلات النظام</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>لا يوجد نتائج لبحثك</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>المستوى</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>معالجة</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>الإجراء:</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>نوع الحدث:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>المستوى:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>التنفيذ:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>التاريخ والوقت</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>معلومات :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستخدم:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>سجل النظام</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>سجل النواة</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>سجل الإقلاع</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>سجل حزم dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>سجل Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>سجل التطبيقات</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>أحداث الإثلاع وإيقاف التشغيل</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>العرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>سجل نظيف</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>تحديث</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>هل أنت متأكد أنك تريد مسح السجل؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>تؤكد</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>اليوم</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 أيام</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 أسبوع</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 شهر</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 أشهر</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>تصدير</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>طارئ</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>إنتباه</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>خطر</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>التصحيح</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>تسجيل الدخول</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>الإقلاع</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation> TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html) </translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>ملف التصدير</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>الفترة :</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status:</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>نوع الحدث:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستعمل :</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>الإجراء:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>سجل الإقلاع</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>سجل إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>سجل تسجيل الدخول</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>التصحيح</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>طارئ</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>إنتباه</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>خطر</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>ملاحظة</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>عارض السجلات</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>عارض السجلات هو أداة مفيدة لعرض سجلات النظام</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>لا يوجد نتائج لبحثك</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>بحث</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>المستوى</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>معالجة</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>معلومات</translation>
    </message>
    <message>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>الإجراء:</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة:</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>نوع الحدث:</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>اسم المستخدم:</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>المستوى:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>التنفيذ:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>التاريخ والوقت</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>معلومات :</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>المستخدم:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>رقم تعريف العملية PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>التاريخ والوقت</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>سجل النظام</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>سجل النواة</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>سجل الإقلاع</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>سجل حزم dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>سجل Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>سجل التطبيقات</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>أحداث الإثلاع وإيقاف التشغيل</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
